import point from './point';
import rectangle from './rectangle';
import ellipse from './ellipse';
import circle from './circle';
import polygon from './polygon';
import line from './line';

export {
    point,
    rectangle,
    ellipse,
    circle,
    polygon,
    line
};
